# Dog API

[![](https://img.shields.io/github/v/tag/thexxiv/dogapi-py?label=version)](https://github.com/thexxiv/dogapi-py/releases/latest) [![](https://img.shields.io/github/license/thexxiv/dogapi-py)](https://github.com/thexxiv/dogapi-py/blob/main/LICENSE)

Dog API client for **Python**.

### Download
[PyPI](https://pypi.org/project/dogceo/)

```
pip install dogceo
```

### Example

```py
from dogceo import multiple_random_images

for dog in multiple_random_images(10):
    print(dog)
```

### Documentation

* [pdoc](https://thexxiv.github.io/dogapi-py)

### License

Dog API client is released under the [Apache License 2.0](https://github.com/thexxiv/dogapi-py/blob/main/LICENSE).

```
 Copyright 2022 XXIV

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
```